@@ -43,7 +43,7 @@ module Net
           self.logger = logger
           @key_files = []
           @key_data = []
-          @use_agent = !(options[:use_agent] == false)
+          @use_agent = options[:use_agent] != false
           @known_identities = {}
           @agent = nil
           @options = options
@@ -182,6 +182,10 @@ module Net
           nil
         end
 
+        def no_keys?
+          key_files.empty? && key_data.empty?
+        end
+
         private
 
         # Prepares identities from user key_files for loading, preserving their order and sources.
@@ -235,7 +239,6 @@ module Net
               else
                 identity
               end
-
             rescue OpenSSL::PKey::RSAError, OpenSSL::PKey::DSAError, OpenSSL::PKey::ECError, OpenSSL::PKey::PKeyError, ArgumentError => e
               if ignore_decryption_errors
                 identity
@@ -260,7 +263,6 @@ module Net
             raise e
           end
         end
-
       end
     end
   end
