@@ -69,7 +69,6 @@ class TestConfig < NetSSHTest
     end
   end
 
-
   def test_for_should_load_all_files_and_translate_to_net_ssh_options
     config = Net::SSH::Config.for("test.host", [config(:exact_match), config(:wild_cards)])
     assert_equal 1234, config[:port]
@@ -125,7 +124,8 @@ class TestConfig < NetSSHTest
       'sendenv'                 => "LC_*",
       'numberofpasswordprompts' => '123',
       'serveraliveinterval'     => '2',
-      'serveralivecountmax'     => '4'
+      'serveralivecountmax'     => '4',
+      'fingerprinthash'         => 'MD5'
     }
 
     net_ssh = Net::SSH::Config.translate(open_ssh)
@@ -146,7 +146,8 @@ class TestConfig < NetSSHTest
     assert_equal 123,       net_ssh[:number_of_password_prompts]
     assert_equal 4,         net_ssh[:keepalive_maxcount]
     assert_equal 2,         net_ssh[:keepalive_interval]
-    assert_equal true,         net_ssh[:keepalive]
+    assert_equal 'MD5',     net_ssh[:fingerprint_hash]
+    assert_equal true, net_ssh[:keepalive]
   end
 
   def test_translate_should_turn_off_authentication_methods
@@ -286,27 +287,101 @@ class TestConfig < NetSSHTest
     assert_equal %w(~/.ssh/id.pem ~/.ssh/id2.pem ~/.ssh/id3.pem), net_ssh[:keys]
   end
 
+  def test_default_files_not_mutable
+    original_default_files = Net::SSH::Config.default_files.clone
+
+    default_files = Net::SSH::Config.default_files
+    default_files.push('garbage')
+
+    assert_equal(original_default_files, Net::SSH::Config.default_files)
+  end
+
+  def test_default_auth_methods_not_mutable
+    original_default_auth_methods = Net::SSH::Config.default_auth_methods.clone
+
+    default_auth_methods = Net::SSH::Config.default_auth_methods
+    default_auth_methods.push('garbage')
+
+    assert_equal(original_default_auth_methods, Net::SSH::Config.default_auth_methods)
+  end
+
+  def test_load_with_match_block
+    config = Net::SSH::Config.load(config(:match), "test.host")
+    net_ssh = Net::SSH::Config.translate(config)
+    assert_equal true, net_ssh[:forward_agent]
+    assert_equal true, net_ssh[:compression]
+    assert_equal 2345, net_ssh[:port]
+  end
+
+  def test_load_with_match_block_with_host
+    data = %q{
+      Match Host foo
+        Port 1234
+        Compression no
+    }
+    with_config_from_data data do |f|
+      config = Net::SSH::Config.load(f, "bar")
+      assert_nil config['port']
+      config = Net::SSH::Config.load(f, "foo")
+      assert_equal 1234, config['port']
+    end
+  end
+
+  def test_load_with_match_block_with_hosts
+    data = %q{
+      Match Host foo,bar
+        Port 1234
+        Compression no
+    }
+    with_config_from_data data do |f|
+      config = Net::SSH::Config.load(f, "bar2")
+      assert_nil config['port']
+      config = Net::SSH::Config.load(f, "bar")
+      assert_equal 1234, config['port']
+      config = Net::SSH::Config.load(f, "foo")
+      assert_equal 1234, config['port']
+    end
+  end
+
+  def test_load_with_match_block_with_hosts_wildcard
+    data = %q{
+      Match Host foo,*.baz.com
+        Port 1234
+        Compression no
+    }
+    with_config_from_data data do |f|
+      config = Net::SSH::Config.load(f, "bar2")
+      assert_nil config['port']
+      config = Net::SSH::Config.load(f, "bbaz.com")
+      assert_nil config['port']
+      config = Net::SSH::Config.load(f, "bar.baz.com")
+      assert_equal 1234, config['port']
+      config = Net::SSH::Config.load(f, "foo")
+      assert_equal 1234, config['port']
+    end
+  end
+
   private
 
-    def with_home_env(value,&block)
-      env_home_before = ENV['HOME']
-      begin
-        ENV['HOME'] = value
-        yield
-      ensure
-        ENV['HOME'] = env_home_before
-      end
+  def with_home_env(value,&block)
+    env_home_before = ENV['HOME']
+    begin
+      ENV['HOME'] = value
+      yield
+    ensure
+      ENV['HOME'] = env_home_before
     end
+  end
 
-    def config(name)
-      "test/configs/#{name}"
-    end
+  def config(name)
+    "test/configs/#{name}"
+  end
 
-    def with_config_from_data(data, &block)
-      Tempfile.open('config') do |f|
-        f.write(data)
-        f.close
-        yield(f.path)
-      end
+  def with_config_from_data(data, &block)
+    Tempfile.open('config') do |f|
+      f.write(data)
+      f.close
+      yield(f.path)
     end
+  end
 end
